#
# spec file for package python-msal-extensions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-msal-extensions
Version:        1.2.0
Release:        1.1
Summary:        Microsoft Authentication Library (MSAL) for Python Extensions
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/AzureAD/microsoft-authentication-library-for-python
Source:         https://files.pythonhosted.org/packages/source/m/msal-extensions/msal_extensions-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-msal >= 1.29 with python-msal < 2.0)
Requires:       (python-portalocker >= 1.4 with python-portalocker < 3.0)
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-msal-extensions < 1.1.0
%endif
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module msal < 2.0}
BuildRequires:  %{python_module msal >= 1.29}
BuildRequires:  %{python_module portalocker < 3.0}
BuildRequires:  %{python_module portalocker >= 1.4}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The Microsoft Authentication Library (MSAL) for Python library enables your app
to access the Microsoft Cloud by supporting authentication of users with Microsoft
Azure Active Directory accounts (AAD) and Microsoft Accounts (MSA) using industry
standard OAuth2 and OpenID Connect.

This packages contains additional extensions.

%prep
%setup -q -n msal_extensions-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%{python_sitelib}/msal_extensions
%{python_sitelib}/msal_extensions-*.dist-info

%changelog
* Tue Jul  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.2.0
  + Remove mentions of Travis CI by @akx in (#126)
  + Set proper lower bound for portalocker dependency,
    drop packaging dependency by @akx in (#125)
  + Switch to MSAL 1.29+'s TokenCache.search()
    by @rayluo in (#131)
- Remove temporary version override
- Update BuildRequires and Requires from setup.py
* Mon May  6 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.2.0b1
  + MSAL Extensions has been updated to work with
    MSAL Python 1.27.* and 1.28.* (#127, #128)
- Adjust upstream source name in spec file
- Override upstream version with 1.2.0~b1
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Use modern RPM macros to express version dependencies
* Thu Mar 21 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Drop support for older Python versions
- Limit Python files matched in %%files section
* Fri Feb  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.1.0
  + Support Python 3.12 by removing dependency on distutils (#120, #123)
  + Dropping Python 2.7 (#122)
* Mon May  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Relax version constraints for python-portalocker in BuildRequires and Requires
* Tue Apr 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.0.0
  + New: Add a new platform-independent build_encrypted_persistence() API. (#87, #110)
  + Remove: Old TokenCache API which has been deprecated for 2 years. (#110)
  + Enhancement: Make all platform-dependent parameters optional (#103)
  + Enhancement: Provide PersistenceEncryptError and PersistenceDecryptError,
    currently raised when encryption on Windows fails. (#108)
  + Enhancement: The data file will be created with 600 permission when
    running in Unix-like systems. (#107)
* Mon Jan  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.1
  + Enhancement: Better concurrency (#61, #63, #100)
  + Bugfix: Now supports user home dir in drive root on Windows (#83, #84)
  + Enhancement: This package can now be run inside container
  + Enhancement: Improvement compatibility with PyInstaller 3.5 on Python 2.7 (#85, #91)
  + Enhancement: Catchable exception when persistence is unavailable (#92, #93)
  + Enhancement: Support dependency portalocker 2.0+ (#94, #97)
  + Enhancement: Improve documentation (#77, #102)
  + Including license in release package (#76)
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Tue Sep  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.0
  + New unified PersistenceNotFound exception is now raised for cases
    where the persistence is not found. (#64, #67)
  + Bugfix: File not found exception is now handled for Python 2.7 as a no-op (#69)
  + Added performance tests for locking behavior (#58)
  + A non-exist persistence on Linux platform would previously return a None.
    Since this release, it will raise PersistenceNotFound exception which becomes
    a consistent behavior on Windows and macOS.
* Fri Aug 28 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.2
  + Bugfix: Restored compatibility with upstream package portalocker version
    < 1.4.0 when running on non-Windows platform (#50)
  + Bugfix: Cache on Windows was not functioning in version 0.2.0 and 0.2.1(#52)
  + Enhancement: Improved readme providing installation and usage instructions (#53)
- from version 0.2.1
  + Functionally the same as 0.2.0, but we change the installation-time and import-time
    dependency of PyGObject to run-time dependency. This would make the installation
    easier for those customers who do not necessarily need to use the Encryption on Linux. (#47)
  + The version 1.6.0+ of upstream package portalocker is only required on Windows.
    Other platforms remain with portalocker 1.0.0+. (#49)
- from version 0.2.0
  + New feature: Support token cache encryption when running on Linux Desktop (#4, #44)
  + Bug fix: The cache lock was not properly removed on Windows 10 (#42, #43)
  + Change: A new set of API PersistedTokenCache is provided. Previous API is now deprecated
    and will be removed in next major release which will likely come within a month:
    WindowsTokenCache, OSXTokenCache, UnencryptedTokenCache, FileTokenCache and TokenCache.
  + Since this release, we have a dependency on PyGObject, when running on Linux.
    You may need to follow its installation steps, or follow our CI setup.
- Update Requires from setup.py
* Tue Feb 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.1.3
